#! /usr/bin/env/python3
# -*- coding=utf-8 -*-
import nacos
import requests
from datetime import datetime
from nacos import NacosException

from conf import *
# from rpc_toolkit import generate_rpc_metadata


def validate_namespace_id():
    if NACOS_NAMESPACE in ['', "public"]:
        return True
    try:
        res = requests.get(f"http://{NACOS_HOST}/nacos/v1/console/namespaces")
        for namespace_info in res.json()["data"]:
            if namespace_info["namespace"] == NACOS_NAMESPACE:
                return True
    except Exception as e:
        raise NacosException(e)
    raise NacosException("namespace id 不存在，请检查配置的 namespace id 是否正确")


def register_nacos_service():
    validate_namespace_id()
    nacos_client = nacos.NacosClient(
        NACOS_HOST,
        namespace=NACOS_NAMESPACE,
        username=NACOS_USER,
        password=NACOS_PASSWORD,
        log_level="ERROR",
        logDir=NACOS_LOG_DIR
    )
    now = datetime.now()
    successful = nacos_client.add_naming_instance(
        NACOS_SERVICE_NAME,
        SERVICE_HOST,
        SERVICE_PORT,
        cluster_name=NACOS_CLUSTER_NAME,
        weight=NACOS_LOAD_WEIGHT,
        metadata=NACOS_METADATA,
        ephemeral=NACOS_EPHEMERAL,
        group_name=NACOS_GROUP_NAME,
        enable=True,
        healthy=True,
        heartbeat_interval=10,
    )
    if not successful:
        raise NacosException("Failed to register in nacos")
    return nacos_client


def deregister_nacos_service(nacos_client):
    nacos_client.remove_naming_instance(
        NACOS_SERVICE_NAME,
        SERVICE_HOST,
        SERVICE_PORT,
        group_name=NACOS_GROUP_NAME,
        cluster_name=NACOS_CLUSTER_NAME,
        ephemeral=NACOS_EPHEMERAL,
    )
